import { BrowserRouter as Router, Routes, Route, Link } from 'react-router-dom';
import { Suspense, lazy } from 'react';

// Layout Components (keep these as direct imports for immediate loading)
import Header from './components/layout/Header';
import Footer from './components/layout/Footer';
import LearningLayout from './components/layout/LearningLayout';

// Lazy load pages for better performance
const Home = lazy(() => import('./pages/Home'));
const About = lazy(() => import('./pages/About'));
const Skills = lazy(() => import('./pages/Skills'));
const Projects = lazy(() => import('./pages/Projects'));
const ProjectDetail = lazy(() => import('./pages/ProjectDetail'));
const Blog = lazy(() => import('./pages/Blog'));
const Learning = lazy(() => import('./pages/Learning'));
const LearningTopic = lazy(() => import('./pages/LearningTopic'));
const Contact = lazy(() => import('./pages/Contact'));
const Privacy = lazy(() => import('./pages/Privacy'));
const Terms = lazy(() => import('./pages/Terms'));

// Context Providers
import { ThemeProvider } from './contexts/ThemeContext';

// Performance and Analytics - Lazy load these
const Analytics = lazy(() => import('./components/Analytics'));
const PerformanceMonitor = lazy(() => import('./components/PerformanceMonitor'));
const CoreWebVitalsMonitor = lazy(() => import('./components/CoreWebVitalsMonitor'));

// Optimized loading component with better UX
const PageLoader = () => (
  <div className="min-h-screen flex items-center justify-center bg-gray-50 dark:bg-gray-900">
    <div className="flex flex-col items-center space-y-4">
      <div className="relative">
        <div className="w-12 h-12 border-4 border-blue-200 dark:border-blue-800 rounded-full"></div>
        <div className="absolute inset-0 w-12 h-12 border-4 border-blue-600 border-t-transparent rounded-full animate-spin"></div>
      </div>
      <div className="text-center">
        <p className="text-gray-600 dark:text-gray-400 font-medium">Loading...</p>
        <p className="text-sm text-gray-500 dark:text-gray-500 mt-1">Preparing your experience</p>
      </div>
    </div>
  </div>
);

function App() {
  return (
    <ThemeProvider>
      <Suspense fallback={null}>
        <PerformanceMonitor />
        <CoreWebVitalsMonitor />
      </Suspense>
      <Router>
        <Suspense fallback={null}>
          <Analytics />
        </Suspense>
        <div className="min-h-screen bg-white dark:bg-gray-800 transition-colors duration-300">
          <Header />
          <main id="main-content" className="flex-1" role="main">
            <Suspense fallback={<PageLoader />}>
              <Routes>
                {/* Main Pages */}
                <Route path="/" element={<Home />} />
                <Route path="/about" element={<About />} />
                <Route path="/skills" element={<Skills />} />

                {/* Projects */}
                <Route path="/projects" element={<Projects />} />
                <Route path="/projects/:id" element={<ProjectDetail />} />
                {/* Blog */}
                <Route path="/blog" element={<Blog />} />{/* Learning Hub - Direct Documentation Structure */}
                <Route path="/learning" element={
                  <LearningLayout>
                    <Learning />
                  </LearningLayout>
                } />
                <Route path="/learning/:pathId/:topicId" element={
                  <LearningLayout>
                    <LearningTopic />
                  </LearningLayout>
                } />

                {/* Contact */}
                <Route path="/contact" element={<Contact />} />

                {/* Legal Pages */}
                <Route path="/privacy" element={<Privacy />} />
                <Route path="/terms" element={<Terms />} />

                {/* 404 Page */}
                <Route path="*" element={
                  <div className="min-h-screen flex items-center justify-center">
                    <div className="text-center">
                      <h1 className="text-6xl font-bold text-gray-300 mb-4">404</h1>
                      <p className="text-xl text-gray-600 mb-8">Page not found</p>
                      <Link to="/" className="btn-primary">Go Home</Link>
                    </div>
                  </div>
                } />
              </Routes>
            </Suspense>
          </main>
          <Footer />
        </div>
      </Router>
    </ThemeProvider>
  );
}

export default App;
